@@ -2,11 +2,15 @@ import contextlib
 import json
 import os
 import sys
-from typing import Optional
+from typing import Optional, Union
 
 import tensorflow as tf
 from tensorflow.python.eager.context import num_gpus
-from tensorflow.python.keras.backend import is_keras_tensor
+
+if tf.__version__[0] > "1":
+    is_keras_tensor = tf.keras.backend.is_keras_tensor
+else:
+    from tensorflow.python.keras.backend import is_keras_tensor
 
 try:
     from tensorflow.python.keras.applications.imagenet_utils import obtain_input_shape
@@ -16,6 +20,17 @@ except ImportError:
         _obtain_input_shape as obtain_input_shape,
     )
 
+try:
+    if tf.__version__[:3] > "2.5":
+        from keras.engine.keras_tensor import KerasTensor
+    else:
+        from tensorflow.python.keras.engine.keras_tensor import KerasTensor
+
+    # Necessary due to https://github.com/tensorflow/tensorflow/issues/44613
+    TensorType = Union[tf.Tensor, KerasTensor]
+except ImportError:
+    TensorType = tf.Tensor
+
 
 def slash_join(*args):
     return "/".join(arg.strip("/") for arg in args)
