@@ -21,10 +21,10 @@ def preprocess_input(image):
     """Preprocesses a Tensor or Numpy array encoding a image.
 
     # Arguments
-    image: Numpy array or symbolic Tensor, 3D.
+        image: Numpy array or symbolic Tensor, 3D.
 
     # Returns
-    Preprocessed Tensor or Numpy array.
+        Preprocessed Tensor or Numpy array.
     """
     if len(image.shape) != 3:
         raise ValueError("Input must be of size [height, width, C>0]")
@@ -50,10 +50,6 @@ class Default(ImageClassification):
 
     def input(self, data, training):
         image = data["image"]
-        # tfds.testing.mock_data currently doesn't correctly handle custom decoders.
-        # See https://github.com/tensorflow/datasets/pull/1861
-        if image.dtype.is_integer:
-            image = tf.image.encode_jpeg(image)
         return preprocess_image_bytes(
             image, is_training=training, image_size=IMAGE_SIZE
         )
